@@ -89,7 +89,7 @@ db_opts = [
     cfg.IntOpt('sql_retry_interval', default=1,
                help=u._("Interval between retries of opening a SQL "
                         "connection.")),
-    cfg.BoolOpt('db_auto_create', default=True,
+    cfg.BoolOpt('db_auto_create', default=False,
                 help=u._("Create the Barbican database on service startup.")),
     cfg.IntOpt('max_limit_paging', default=100,
                help=u._("Maximum page size for the 'limit' paging URL "
@@ -183,7 +183,22 @@ ks_queue_opts = [
                         "will be dispatched to one of the servers in a "
                         "round-robin fashion. That's why Barbican service "
                         "should have its own dedicated notification queue so "
-                        "that it receives all of Keystone notifications.")),
+                        "that it receives all of Keystone notifications. "
+                        "Alternatively if the chosen oslo.messaging backend "
+                        "supports listener pooling (for example rabbitmq), "
+                        "setting a non-default 'pool_name' option "
+                        "should be preferred.")),
+    cfg.StrOpt('pool_name',
+               help=u._("Pool name for notifications listener. "
+                        "Setting this to a distinctive value will allow "
+                        "barbican notifications listener to receive its own "
+                        "copy of all messages from the topic without "
+                        "without interfering with other services listening "
+                        "on the same topic. This feature is supported only "
+                        "by some oslo.messaging backends "
+                        "(in particilar by rabbitmq) and for those it is "
+                        "preferrable to use it instead of separate "
+                        "notification topic for barbican.")),
     cfg.BoolOpt('allow_requeue', default=False,
                 help=u._('True enables requeue feature in case of notification'
                          ' processing error. Enable this only when underlying '
