@@ -58,62 +58,32 @@ def get_invalid_property(validation_error):
         return validation_error.schema_path[1]
 
 
-def validate_ca_id(project_id, order_meta):
-    ca_id = order_meta.get('ca_id')
-    if not ca_id:
-        return
-
-    ca_repo = repo.get_ca_repository()
-    ca = ca_repo.get(ca_id, suppress_exception=True)
-    if not ca:
-        raise exception.InvalidCAID(ca_id=ca_id)
-
-    if ca.project_id and ca.project_id != project_id:
-        raise exception.UnauthorizedSubCA()
-
-    project_ca_repo = repo.get_project_ca_repository()
-    project_cas, offset, limit, total = project_ca_repo.get_by_create_date(
-        project_id=project_id,
-        suppress_exception=True
-    )
-    if total < 1:
-        return
-
-    for project_ca in project_cas:
-        if ca.id == project_ca.ca_id:
-            return
-
-    raise exception.CANotDefinedForProject(
-        ca_id=ca_id,
-        project_id=project_id)
-
-
 def validate_stored_key_rsa_container(project_id, container_ref, req):
-        try:
-            container_id = hrefs.get_container_id_from_ref(container_ref)
-        except Exception:
-            reason = u._("Bad Container Reference {ref}").format(
-                ref=container_ref
-            )
-            raise exception.InvalidContainer(reason=reason)
+    try:
+        container_id = hrefs.get_container_id_from_ref(container_ref)
+    except Exception:
+        reason = u._("Bad Container Reference {ref}").format(
+            ref=container_ref
+        )
+        raise exception.InvalidContainer(reason=reason)
 
-        container_repo = repo.get_container_repository()
+    container_repo = repo.get_container_repository()
 
-        container = container_repo.get_container_by_id(entity_id=container_id,
-                                                       suppress_exception=True)
-        if not container:
-            reason = u._("Container Not Found")
-            raise exception.InvalidContainer(reason=reason)
+    container = container_repo.get_container_by_id(entity_id=container_id,
+                                                   suppress_exception=True)
+    if not container:
+        reason = u._("Container Not Found")
+        raise exception.InvalidContainer(reason=reason)
 
-        if container.type != 'rsa':
-            reason = u._("Container Wrong Type")
-            raise exception.InvalidContainer(reason=reason)
+    if container.type != 'rsa':
+        reason = u._("Container Wrong Type")
+        raise exception.InvalidContainer(reason=reason)
 
-        ctxt = controllers._get_barbican_context(req)
-        inst = controllers.containers.ContainerController(container)
-        controllers._do_enforce_rbac(inst, req,
-                                     controllers.containers.CONTAINER_GET,
-                                     ctxt)
+    ctxt = controllers._get_barbican_context(req)
+    inst = controllers.containers.ContainerController(container)
+    controllers._do_enforce_rbac(inst, req,
+                                 controllers.containers.CONTAINER_GET,
+                                 ctxt)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -257,8 +227,7 @@ class NewSecretValidator(ValidatorBase):
                     mime_types.is_supported(content_type),
                     schema_name,
                     u._("payload_content_type is not one of {supported}"
-                        ).format(supplied=content_type,
-                                 supported=mime_types.SUPPORTED),
+                        ).format(supported=mime_types.SUPPORTED),
                     "payload_content_type")
 
         return json_data
@@ -279,7 +248,7 @@ class NewSecretValidator(ValidatorBase):
                 expiration_tz = timeutils.parse_isotime(expiration_raw.strip())
                 expiration = timeutils.normalize_time(expiration_tz)
             except ValueError:
-                LOG.exception(u._("Problem parsing expiration date"))
+                LOG.exception("Problem parsing expiration date")
                 raise exception.InvalidObject(
                     schema=schema_name,
                     reason=u._("Invalid date for 'expiration'"),
@@ -316,9 +285,8 @@ class NewSecretValidator(ValidatorBase):
         self._assert_validity(
             mime_types.is_supported(content_type),
             schema_name,
-            u._("payload_content_type {supplied} is not one of {supported}"
-                ).format(supplied=content_type,
-                         supported=mime_types.SUPPORTED),
+            u._("payload_content_type is not one of {supported}"
+                ).format(supported=mime_types.SUPPORTED),
             "payload_content_type")
 
         self._assert_validity(
@@ -336,7 +304,7 @@ class NewSecretValidator(ValidatorBase):
             try:
                 base64.b64decode(payload)
             except Exception:
-                LOG.exception(u._("Problem parsing payload"))
+                LOG.exception("Problem parsing payload")
                 raise exception.InvalidObject(
                     schema=schema_name,
                     reason=u._("Invalid payload for payload_content_encoding"),
@@ -377,7 +345,7 @@ class NewSecretMetadataValidator(ValidatorBase):
         """Extracts and returns the metadata from the JSON data."""
         metadata = json_data['metadata']
 
-        for key in metadata:
+        for key in list(metadata):
             # make sure key is a string and url-safe.
             if not isinstance(key, six.string_types):
                 raise exception.InvalidMetadataRequest()
@@ -689,7 +657,7 @@ class TypeOrderValidator(ValidatorBase, CACommonHelpersMixin):
                 expiration_tz = timeutils.parse_isotime(expiration_raw)
                 expiration = timeutils.normalize_time(expiration_tz)
             except ValueError:
-                LOG.exception(u._("Problem parsing expiration date"))
+                LOG.exception("Problem parsing expiration date")
                 raise exception.InvalidObject(schema=schema_name,
                                               reason=u._("Invalid date "
                                                          "for 'expiration'"),
@@ -762,8 +730,8 @@ class ContainerConsumerValidator(ValidatorBase):
         self.schema = {
             "type": "object",
             "properties": {
-                "URL": {"type": "string"},
-                "name": {"type": "string", "maxLength": 255}
+                "URL": {"type": "string", "minLength": 1},
+                "name": {"type": "string", "maxLength": 255, "minLength": 1}
             },
             "required": ["name", "URL"]
         }
@@ -1036,3 +1004,35 @@ class NewCAValidator(ValidatorBase, CACommonHelpersMixin):
         subject_dn = json_data['subject_dn']
         self._validate_subject_dn_data(subject_dn)
         return json_data
+
+
+class SecretConsumerValidator(ValidatorBase):
+    """Validate a new Secret Consumer."""
+
+    def __init__(self):
+        self.name = "Secret Consumer"
+
+        self.schema = {
+            "type": "object",
+            "properties": {
+                "service": {
+                    "type": "string",
+                    "maxLength": 255,
+                    "minLength": 1,
+                },
+                "resource_type": {
+                    "type": "string",
+                    "maxLength": 255,
+                    "minLength": 1,
+                },
+                "resource_id": {"type": "string", "minLength": 1},
+            },
+            "required": ["service", "resource_type", "resource_id"],
+        }
+
+    def validate(self, json_data, parent_schema=None):
+        schema_name = self._full_name(parent_schema)
+
+        self._assert_schema_is_valid(json_data, schema_name)
+
+        return json_data
