@@ -69,6 +69,9 @@ p11_crypto_plugin_opts = [
     cfg.StrOpt('hmac_keygen_mechanism',
                help=u._('HMAC Key Generation Algorithm'),
                default='CKM_AES_KEY_GEN'),
+    cfg.StrOpt('hmac_keywrap_mechanism',
+               help=u._('HMAC key wrap mechanism'),
+               default='CKM_SHA256_HMAC'),
     cfg.StrOpt('seed_file',
                help=u._('File to pull entropy for seeding RNG'),
                default=''),
@@ -78,9 +81,13 @@ p11_crypto_plugin_opts = [
     cfg.StrOpt('plugin_name',
                help=u._('User friendly plugin name'),
                default='PKCS11 HSM'),
-    cfg.BoolOpt('generate_iv',
-                help=u._('Flag for plugin generated iv case'),
-                default=False),
+    cfg.BoolOpt('aes_gcm_generate_iv',
+                help=u._('Generate IVs for CKM_AES_GCM mechanism.'),
+                default=True, deprecated_name='generate_iv'),
+    cfg.BoolOpt('always_set_cka_sensitive',
+                help=u._('Always set CKA_SENSITIVE=CK_TRUE including '
+                         'CKA_EXTRACTABLE=CK_TRUE keys.'),
+                default=True),
 ]
 CONF.register_group(p11_crypto_plugin_group)
 CONF.register_opts(p11_crypto_plugin_opts, group=p11_crypto_plugin_group)
@@ -301,7 +308,9 @@ class P11CryptoPlugin(plugin.CryptoPluginBase):
             encryption_mechanism=plugin_conf.encryption_mechanism,
             ffi=ffi,
             seed_random_buffer=seed_random_buffer,
-            generate_iv=plugin_conf.generate_iv,
+            generate_iv=plugin_conf.aes_gcm_generate_iv,
+            always_set_cka_sensitive=plugin_conf.always_set_cka_sensitive,
+            hmac_keywrap_mechanism=plugin_conf.hmac_keywrap_mechanism
         )
 
     def _reinitialize_pkcs11(self):
@@ -405,36 +414,3 @@ class P11CryptoPlugin(plugin.CryptoPluginBase):
             'mkek_label': self.mkek_label,
             'hmac_label': self.hmac_label
         }
-
-    def _generate_mkek(self, key_length, key_label):
-        with self.mk_cache_lock, self.caching_session_lock:
-            session = self.caching_session
-            if key_label in self.mk_cache or \
-                    self.pkcs11.get_key_handle(key_label, session) is not None:
-                raise exception.P11CryptoPluginKeyException(
-                    u._("A master key with that label already exists")
-                )
-            mk = self.pkcs11.generate_key(
-                'CKK_AES', key_length, 'CKM_AES_KEY_GEN', session,
-                key_label=key_label,
-                encrypt=True, wrap=True, master_key=True
-            )
-
-            self.mk_cache[key_label] = mk
-        return mk
-
-    def _generate_mkhk(self, key_length, key_label):
-        with self.mk_cache_lock, self.caching_session_lock:
-            session = self.caching_session
-            if key_label in self.mk_cache or \
-                    self.pkcs11.get_key_handle(key_label, session, 'hmac') \
-                    is not None:
-                raise exception.P11CryptoPluginKeyException(
-                    u._("A master key with that label already exists")
-                )
-            mk = self.pkcs11.generate_key(
-                self.hmac_key_type, key_length, self.hmac_keygen_mechanism,
-                session, key_label, sign=True, master_key=True
-            )
-            self.mk_cache[key_label] = mk
-        return mk
