@@ -18,9 +18,8 @@ For typical-flow business logic tests of these classes, see the
 'resources_test.py' module.
 """
 import os
+from unittest import mock
 
-import mock
-from oslo_policy import policy
 from webob import exc
 
 from barbican.api.controllers import consumers
@@ -29,7 +28,9 @@ from barbican.api.controllers import orders
 from barbican.api.controllers import secrets
 from barbican.api.controllers import secretstores
 from barbican.api.controllers import versions
+from barbican.common import accept as common_accept
 from barbican.common import config
+from barbican.common import policy
 from barbican import context
 from barbican.model import models
 from barbican.tests import utils
@@ -41,7 +42,8 @@ TEST_VAR_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__),
 
 CONF = config.new_config()
 
-ENFORCER = policy.Enforcer(CONF)
+policy.init()
+ENFORCER = policy.ENFORCER
 
 
 class TestableResource(object):
@@ -114,6 +116,14 @@ class PreferredSecretStoreResource(TestableResource):
     controller_cls = secretstores.PreferredSecretStoreController
 
 
+class SecretConsumersResource(TestableResource):
+    controller_cls = consumers.SecretConsumersController
+
+
+class SecretConsumerResource(TestableResource):
+    controller_cls = consumers.SecretConsumerController
+
+
 class BaseTestCase(utils.BaseTestCase, utils.MockModelRepositoryMixin):
 
     def setUp(self):
@@ -130,18 +140,15 @@ class BaseTestCase(utils.BaseTestCase, utils.MockModelRepositoryMixin):
         req.get_param.return_value = None
 
         kwargs = {
-            'user': user_id,
-            'project': project_id,
+            'user_id': user_id,
+            'project_id': project_id,
             'roles': roles or [],
             'policy_enforcer': self.policy_enforcer,
         }
         req.environ = {}
         req.environ['barbican.context'] = context.RequestContext(**kwargs)
         req.content_type = content_type
-        if accept:
-            req.accept.header_value.return_value = accept
-        else:
-            req.accept = None
+        req.accept = common_accept.create_accept_header(accept)
 
         return req
 
@@ -1276,3 +1283,99 @@ class WhenTestingPreferredSecretStoreResource(BaseTestCase):
 
     def _invoke_on_post(self):
         self.resource.on_post(self.req, self.resp)
+
+
+class WhenTestingSecretConsumersResource(BaseTestCase):
+    """RBAC tests for barbican.api.resources.SecretConsumersResource"""
+    def setUp(self):
+        super(WhenTestingSecretConsumersResource, self).setUp()
+
+        self.external_project_id = '12345project'
+        self.secret_id = '12345secret'
+
+        # Force an error on GET calls that pass RBAC, as we are not testing
+        #   such flows in this test module.
+        self.consumer_repo = mock.MagicMock()
+        get_by_secret_id = mock.MagicMock(return_value=None,
+                                          side_effect=self
+                                          ._generate_get_error())
+        self.consumer_repo.get_by_secret_id = get_by_secret_id
+
+        self.setup_project_repository_mock()
+        self.setup_secret_consumer_repository_mock(self.consumer_repo)
+        self.setup_secret_repository_mock()
+
+        self.resource = SecretConsumersResource(secret_id=self.secret_id)
+
+    def test_rules_should_be_loaded(self):
+        self.assertIsNotNone(self.policy_enforcer.rules)
+
+    def test_should_pass_create_consumer(self):
+        self._assert_pass_rbac(['admin'], self._invoke_on_post,
+                               content_type='application/json')
+
+    def test_should_raise_create_consumer(self):
+        self._assert_fail_rbac([None, 'audit', 'observer', 'creator', 'bogus'],
+                               self._invoke_on_post,
+                               content_type='application/json')
+
+    def test_should_pass_delete_consumer(self):
+        self._assert_pass_rbac(['admin'], self._invoke_on_delete,
+                               content_type='application/json')
+
+    def test_should_raise_delete_consumer(self):
+        self._assert_fail_rbac([None, 'audit', 'observer', 'creator', 'bogus'],
+                               self._invoke_on_delete)
+
+    def test_should_pass_get_consumers(self):
+        self._assert_pass_rbac(['admin', 'observer', 'creator', 'audit'],
+                               self._invoke_on_get,
+                               content_type='application/json')
+
+    def test_should_raise_get_consumers(self):
+        self._assert_fail_rbac([None, 'bogus'],
+                               self._invoke_on_get,
+                               content_type='application/json')
+
+    def _invoke_on_post(self):
+        self.resource.on_post(self.req, self.resp)
+
+    def _invoke_on_delete(self):
+        self.resource.on_delete(self.req, self.resp)
+
+    def _invoke_on_get(self):
+        self.resource.on_get(self.req, self.resp)
+
+
+class WhenTestingSecretConsumerResource(BaseTestCase):
+    """RBAC tests for barbican.api.resources.SecretConsumerResource"""
+    def setUp(self):
+        super(WhenTestingSecretConsumerResource, self).setUp()
+
+        self.external_project_id = '12345project'
+        self.consumer_id = '12345consumer'
+
+        # Force an error on GET calls that pass RBAC, as we are not testing
+        #   such flows in this test module.
+        self.consumer_repo = mock.MagicMock()
+        fail_method = mock.MagicMock(return_value=None,
+                                     side_effect=self._generate_get_error())
+        self.consumer_repo.get = fail_method
+
+        self.setup_project_repository_mock()
+        self.setup_secret_consumer_repository_mock(self.consumer_repo)
+        self.resource = SecretConsumerResource(consumer_id=self.consumer_id)
+
+    def test_rules_should_be_loaded(self):
+        self.assertIsNotNone(self.policy_enforcer.rules)
+
+    def test_should_pass_get_consumer(self):
+        self._assert_pass_rbac(['admin', 'observer', 'creator', 'audit'],
+                               self._invoke_on_get)
+
+    def test_should_raise_get_consumer(self):
+        self._assert_fail_rbac([None, 'bogus'],
+                               self._invoke_on_get)
+
+    def _invoke_on_get(self):
+        self.resource.on_get(self.req, self.resp)
