@@ -13,7 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
+from unittest import mock
+
 import six
 
 from barbican.common import exception as ex
@@ -23,9 +24,6 @@ from barbican.plugin.crypto import p11_crypto
 from barbican.plugin.crypto import pkcs11
 from barbican.tests import utils
 
-if six.PY3:
-    long = int
-
 
 def generate_random_effect(length, session):
     return b'0' * length
@@ -37,15 +35,15 @@ class WhenTestingP11CryptoPlugin(utils.BaseTestCase):
         super(WhenTestingP11CryptoPlugin, self).setUp()
 
         self.pkcs11 = mock.Mock()
-        self.pkcs11.get_session.return_value = long(1)
+        self.pkcs11.get_session.return_value = int(1)
         self.pkcs11.return_session.return_value = None
         self.pkcs11.generate_random.side_effect = generate_random_effect
-        self.pkcs11.get_key_handle.return_value = long(2)
+        self.pkcs11.get_key_handle.return_value = int(2)
         self.pkcs11.encrypt.return_value = {'iv': b'0', 'ct': b'0'}
         self.pkcs11.decrypt.return_value = b'0'
-        self.pkcs11.generate_key.return_value = long(3)
+        self.pkcs11.generate_key.return_value = int(3)
         self.pkcs11.wrap_key.return_value = {'iv': b'1', 'wrapped_key': b'1'}
-        self.pkcs11.unwrap_key.return_value = long(4)
+        self.pkcs11.unwrap_key.return_value = int(4)
         self.pkcs11.compute_hmac.return_value = b'1'
         self.pkcs11.verify_hmac.return_value = None
         self.pkcs11.destroy_object.return_value = None
@@ -63,6 +61,8 @@ class WhenTestingP11CryptoPlugin(utils.BaseTestCase):
         self.cfg_mock.p11_crypto_plugin.encryption_mechanism = 'CKM_AES_CBC'
         self.cfg_mock.p11_crypto_plugin.seed_file = ''
         self.cfg_mock.p11_crypto_plugin.seed_length = 32
+        self.cfg_mock.p11_crypto_plugin.hmac_keywrap_mechanism = \
+            'CKM_SHA256_HMAC'
 
         self.plugin_name = 'Test PKCS11 plugin'
         self.cfg_mock.p11_crypto_plugin.plugin_name = self.plugin_name
@@ -280,44 +280,6 @@ class WhenTestingP11CryptoPlugin(utils.BaseTestCase):
         self.plugin.pkek_cache['expired_kek'] = p11_crypto.CachedKEK(4, 0)
         self.assertIsNone(self.plugin._pkek_cache_get('expired_kek'))
 
-    def test_generate_mkek(self):
-        self.pkcs11.get_key_handle.return_value = None
-
-        mkek = self.plugin._generate_mkek(256, 'mkek_label_2')
-        self.assertEqual(3, mkek)
-
-        self.assertEqual(3, self.pkcs11.get_key_handle.call_count)
-        self.assertEqual(1, self.pkcs11.generate_key.call_count)
-
-    def test_cached_generate_mkek(self):
-        self.assertRaises(ex.P11CryptoPluginKeyException,
-                          self.plugin._generate_mkek, 256, 'mkek_label')
-        self.assertEqual(2, self.pkcs11.get_key_handle.call_count)
-
-    def test_existing_generate_mkek(self):
-        self.assertRaises(ex.P11CryptoPluginKeyException,
-                          self.plugin._generate_mkek, 256, 'mkek2_label')
-        self.assertEqual(3, self.pkcs11.get_key_handle.call_count)
-
-    def test_generate_mkhk(self):
-        self.pkcs11.get_key_handle.return_value = None
-
-        mkhk = self.plugin._generate_mkhk(256, 'mkhk_label_2')
-        self.assertEqual(3, mkhk)
-
-        self.assertEqual(3, self.pkcs11.get_key_handle.call_count)
-        self.assertEqual(1, self.pkcs11.generate_key.call_count)
-
-    def test_cached_generate_mkhk(self):
-        self.assertRaises(ex.P11CryptoPluginKeyException,
-                          self.plugin._generate_mkhk, 256, 'hmac_label')
-        self.assertEqual(2, self.pkcs11.get_key_handle.call_count)
-
-    def test_existing_generate_mkhk(self):
-        self.assertRaises(ex.P11CryptoPluginKeyException,
-                          self.plugin._generate_mkhk, 256, 'mkhk2_label')
-        self.assertEqual(3, self.pkcs11.get_key_handle.call_count)
-
     def test_create_pkcs11(self):
         def _generate_random(session, buf, length):
             ffi.buffer(buf)[:] = b'0' * length
