@@ -11,16 +11,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
-import six
+from unittest import mock
+
 
 from barbican.common import exception
 from barbican.plugin.crypto import pkcs11
 from barbican.tests import utils
 
-if six.PY3:
-    long = int
-
 
 class WhenTestingPKCS11(utils.BaseTestCase):
 
@@ -60,12 +57,14 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         self.cfg_mock.rw_session = False
         self.cfg_mock.slot_id = 1
         self.cfg_mock.encryption_mechanism = 'CKM_AES_CBC'
+        self.cfg_mock.hmac_keywrap_mechanism = 'CKM_SHA256_HMAC'
 
         self.pkcs11 = pkcs11.PKCS11(
             self.cfg_mock.library_path, self.cfg_mock.login_passphrase,
             self.cfg_mock.rw_session, self.cfg_mock.slot_id,
             self.cfg_mock.encryption_mechanism,
-            ffi=self.ffi
+            ffi=self.ffi,
+            hmac_keywrap_mechanism=self.cfg_mock.hmac_keywrap_mechanism
         )
 
     def _generate_random(self, session, buf, length):
@@ -87,16 +86,16 @@ class WhenTestingPKCS11(utils.BaseTestCase):
         return pkcs11.CKR_OK
 
     def _open_session(self, *args, **kwargs):
-        args[4][0] = long(1)
+        args[4][0] = int(1)
         return pkcs11.CKR_OK
 
     def _find_objects_one(self, session, obj_handle_ptr, max_count, count):
-        obj_handle_ptr[0] = long(2)
+        obj_handle_ptr[0] = int(2)
         count[0] = 1
         return pkcs11.CKR_OK
 
     def _find_objects_two(self, session, obj_handle_ptr, max_count, count):
-        obj_handle_ptr[0] = long(2)
+        obj_handle_ptr[0] = int(2)
         count[0] = 2
         return pkcs11.CKR_OK
 
@@ -106,7 +105,7 @@ class WhenTestingPKCS11(utils.BaseTestCase):
 
     def _generate_key(self, session, mech, attributes, attributes_len,
                       obj_handle_ptr):
-        obj_handle_ptr[0] = long(3)
+        obj_handle_ptr[0] = int(3)
         return pkcs11.CKR_OK
 
     def _encrypt(self, session, pt, pt_len, ct, ct_len):
@@ -125,14 +124,14 @@ class WhenTestingPKCS11(utils.BaseTestCase):
     def _wrap_key(self, *args, **kwargs):
         wrapped_key = args[4]
         wrapped_key_len = args[5]
-        wrapped_key_len[0] = long(16)
+        wrapped_key_len[0] = int(16)
         if wrapped_key != self.ffi.NULL:
             self.ffi.buffer(wrapped_key)[:] = b'0' * 16
         return pkcs11.CKR_OK
 
     def _unwrap_key(self, *args, **kwargs):
         unwrapped_key = args[7]
-        unwrapped_key[0] = long(1)
+        unwrapped_key[0] = int(1)
         return pkcs11.CKR_OK
 
     def _sign(self, *args, **kwargs):
@@ -397,3 +396,9 @@ class WhenTestingPKCS11(utils.BaseTestCase):
     def test_check_error_with_token_error(self):
         self.assertRaises(exception.P11CryptoTokenException,
                           self.pkcs11._check_error, 0xe0)
+
+    def test_converting_unicode_to_bytes(self):
+        self.assertEqual(b'foo', pkcs11._to_bytes(u'foo'))
+
+    def test_converting_default_str_type_to_bytes(self):
+        self.assertEqual(b'foo', pkcs11._to_bytes('foo'))
