@@ -15,10 +15,13 @@
 
 import base64
 import datetime
+from unittest import mock
 
-from Crypto.PublicKey import RSA
-import mock
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.primitives import serialization
 from OpenSSL import crypto
+from oslo_utils import encodeutils
 
 from barbican.common import exception as excep
 from barbican.common import hrefs
@@ -447,9 +450,6 @@ class BaseCertificateRequestsTestCase(database_utils.RepositoryTestCase):
 class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
     """Tests the 'issue_certificate_request()' function."""
 
-    def setUp(self):
-        super(WhenIssuingCertificateRequests, self).setUp()
-
     def tearDown(self):
         super(WhenIssuingCertificateRequests, self).tearDown()
 
@@ -559,13 +559,28 @@ class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
         )
         passphrase = "my secret passphrase"
 
-        private_key = RSA.generate(2048, None, None, 65537)
-        public_key = private_key.publickey()
+        private_key = rsa.generate_private_key(
+            public_exponent=65537,
+            key_size=2048,
+            backend=default_backend()
+        )
 
-        private_key_pem = private_key.exportKey('PEM', passphrase, 8)
+        public_key = private_key.public_key()
+
+        private_key_pem = private_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.PKCS8,
+            encryption_algorithm=serialization.
+            BestAvailableEncryption(encodeutils.safe_encode(passphrase))
+        )
         self.private_key_value = base64.b64encode(private_key_pem)
-        public_key_pem = public_key.exportKey()
+
+        public_key_pem = public_key.public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.PKCS1
+        )
         self.public_key_value = base64.b64encode(public_key_pem)
+
         self.passphrase_value = base64.b64encode(passphrase.encode('utf-8'))
 
         self.store_plugin.get_secret.side_effect = self.stored_key_side_effect
@@ -582,12 +597,26 @@ class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
     def test_should_return_for_pycrypto_stored_key_without_passphrase(self):
         self.order_meta.update(self.stored_key_meta)
 
-        private_key = RSA.generate(2048, None, None, 65537)
-        public_key = private_key.publickey()
+        private_key = rsa.generate_private_key(
+            public_exponent=65537,
+            key_size=2048,
+            backend=default_backend()
+        )
 
-        self.private_key_value = base64.b64encode(
-            private_key.exportKey('PEM', None, 8))
-        self.public_key_value = base64.b64encode(public_key.exportKey())
+        public_key = private_key.public_key()
+
+        private_key_pem = private_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.PKCS8,
+            encryption_algorithm=serialization.NoEncryption()
+        )
+        self.private_key_value = base64.b64encode(private_key_pem)
+
+        public_key_pem = public_key.public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.PKCS1
+        )
+        self.public_key_value = base64.b64encode(public_key_pem)
 
         self.store_plugin.get_secret.side_effect = self.stored_key_side_effect
         self._test_should_return_waiting_for_ca(
@@ -602,11 +631,27 @@ class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
 
     def test_should_raise_for_pycrypto_stored_key_no_container(self):
         self.order_meta.update(self.stored_key_meta)
-        private_key = RSA.generate(2048, None, None, 65537)
-        public_key = private_key.publickey()
 
-        self.private_key_value = private_key.exportKey('PEM', None, 8)
-        self.public_key_value = public_key.exportKey()
+        private_key = rsa.generate_private_key(
+            public_exponent=65537,
+            key_size=2048,
+            backend=default_backend()
+        )
+
+        public_key = private_key.public_key()
+
+        private_key_pem = private_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.PKCS8,
+            encryption_algorithm=serialization.NoEncryption()
+        )
+        self.private_key_value = base64.b64encode(private_key_pem)
+
+        public_key_pem = public_key.public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.PKCS1
+        )
+        self.public_key_value = base64.b64encode(public_key_pem)
 
         self.store_plugin.get_secret.side_effect = self.stored_key_side_effect
         self.result.status = cert_man.CertificateStatus.WAITING_FOR_CA
@@ -620,13 +665,27 @@ class WhenIssuingCertificateRequests(BaseCertificateRequestsTestCase):
 
     def test_should_raise_for_pycrypto_stored_key_no_private_key(self):
         self.order_meta.update(self.stored_key_meta)
-        private_key = RSA.generate(2048, None, None, 65537)
-        public_key = private_key.publickey()
 
-        self.private_key_value = base64.b64encode(
-            private_key.exportKey('PEM', None, 8))
-        self.public_key_value = base64.b64encode(
-            public_key.exportKey())
+        private_key = rsa.generate_private_key(
+            public_exponent=65537,
+            key_size=2048,
+            backend=default_backend()
+        )
+
+        public_key = private_key.public_key()
+
+        private_key_pem = private_key.private_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PrivateFormat.PKCS8,
+            encryption_algorithm=serialization.NoEncryption()
+        )
+        self.private_key_value = base64.b64encode(private_key_pem)
+
+        public_key_pem = public_key.public_bytes(
+            encoding=serialization.Encoding.PEM,
+            format=serialization.PublicFormat.PKCS1
+        )
+        self.public_key_value = base64.b64encode(public_key_pem)
 
         self.store_plugin.get_secret.side_effect = self.stored_key_side_effect
         self.result.status = cert_man.CertificateStatus.WAITING_FOR_CA
